@@ -33,6 +33,7 @@
 #  define KPIPEWIRE_DECL_DEPRECATED_NO_EXPORT KPIPEWIRE_NO_EXPORT KPIPEWIRE_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KPIPEWIRE_NO_DEPRECATED
 #    define KPIPEWIRE_NO_DEPRECATED
@@ -61,7 +62,7 @@
 #define KPIPEWIRE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPIPEWIRE_NO_DEPRECATED
-#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6005a
+#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60305
 #endif
 #ifdef KPIPEWIRE_NO_DEPRECATED_WARNINGS
 #  define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0
@@ -71,7 +72,7 @@
 #  ifdef KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0x6005a
+#    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0x60305
 #  endif
 #endif
 
